@@ -29,7 +29,7 @@ Editor::Editor(const Kolf::ItemFactory& factory, QWidget *parent)
 	: QWidget(parent)
 	, m_factory(factory)
 {
-	config = 0;
+	config = nullptr;
 
 	hlayout = new QHBoxLayout(this);
 
@@ -41,8 +41,8 @@ Editor::Editor(const Kolf::ItemFactory& factory, QWidget *parent)
 	hlayout->setStretchFactor(vlayout, 2);
 
 	//populate type list
-	foreach (const Kolf::ItemMetadata& metadata, factory.knownTypes())
-	{
+	const auto knownTypes = factory.knownTypes();
+	for (const Kolf::ItemMetadata& metadata : knownTypes) {
 		QListWidgetItem* item = new QListWidgetItem(metadata.name);
 		item->setData(Qt::UserRole, metadata.identifier);
 		m_typeList->addItem(item);
@@ -52,7 +52,7 @@ Editor::Editor(const Kolf::ItemFactory& factory, QWidget *parent)
 
 void Editor::listboxExecuted(QListWidgetItem* item)
 {
-	emit addNewItem(item->data(Qt::UserRole).toString()); //data(UserRole) contains the type identifier
+	Q_EMIT addNewItem(item->data(Qt::UserRole).toString()); //data(UserRole) contains the type identifier
 }
 
 void Editor::setItem(CanvasItem *item)
